@@ -57,6 +57,7 @@ typedef enum
     ADM_VDPAU_VC1=3
 }ADM_VDPAU_TYPE;
 
+
 /**
     \fn markSurfaceUsed
     \brief mark the surfave as used. Can be called multiple time.
@@ -282,14 +283,6 @@ decoderFFVDPAU::decoderFFVDPAU(uint32_t w, uint32_t h,uint32_t fcc, uint32_t ext
         alive=true;
         scratch=NULL;
      
-        _context->opaque          = this;
-        _context->get_buffer      = ADM_VDPAUgetBuffer;
-        _context->release_buffer  = ADM_VDPAUreleaseBuffer;
-        _context->draw_horiz_band = draw;
-        _context->slice_flags     = SLICE_FLAG_CODED_ORDER|SLICE_FLAG_ALLOW_FIELD;
-        _context->extradata = (uint8_t *) _extraDataCopy;
-        _context->extradata_size  = (int) extraDataLen;
-        _context->get_format      = vdpauGetFormat;
         vdpau=(void *)new vdpauContext;
         VDPAU->vdpDecoder=VDP_INVALID_HANDLE;
         ADM_VDPAU_TYPE vdpauType=ADM_VDPAU_INVALID;
@@ -307,15 +300,15 @@ decoderFFVDPAU::decoderFFVDPAU(uint32_t w, uint32_t h,uint32_t fcc, uint32_t ext
         switch(vdpauType)
         {
             case ADM_VDPAU_VC1  : vdpDecoder=VDP_DECODER_PROFILE_VC1_ADVANCED;
-                                  WRAP_OpenByName(vc1_vdpau,CODEC_ID_VC1);
+                                  WRAP_Open_TemplateVdpauByName("vc1_vdpau",CODEC_ID_VC1);
                                   break;
 
             case ADM_VDPAU_H264 : vdpDecoder=VDP_DECODER_PROFILE_H264_HIGH;
-                                  WRAP_OpenByName(h264_vdpau,CODEC_ID_H264);
+                                  WRAP_Open_TemplateVdpauByName("h264_vdpau",CODEC_ID_H264);
                                   break;
             case ADM_VDPAU_MPEG2: 
                                   vdpDecoder=VDP_DECODER_PROFILE_MPEG2_MAIN;
-                                  WRAP_OpenByName(mpegvideo_vdpau,CODEC_ID_MPEG2VIDEO);
+                                  WRAP_Open_TemplateVdpauByName("mpegvideo_vdpau",CODEC_ID_MPEG2VIDEO);
                                   break;
             default: ADM_assert(0);break;
         }
@@ -323,8 +316,11 @@ decoderFFVDPAU::decoderFFVDPAU(uint32_t w, uint32_t h,uint32_t fcc, uint32_t ext
         // Now instantiate our VDPAU surface & decoder
         for(int i=0;i<NB_SURFACE;i++)
             VDPAU->renders[i]=NULL;
-        
-        if(VDP_STATUS_OK!=admVdpau::decoderCreate(vdpDecoder, w,h,15,&(VDPAU->vdpDecoder)))
+       
+        int widthToUse=admVdpau::dimensionRoundUp(w);
+        int heightToUse=admVdpau::dimensionRoundUp(h);
+ 
+        if(VDP_STATUS_OK!=admVdpau::decoderCreate(vdpDecoder, widthToUse,heightToUse,15,&(VDPAU->vdpDecoder)))
         {
             ADM_error("Cannot create VDPAU decoder\n");
             alive=false;
@@ -335,7 +331,7 @@ decoderFFVDPAU::decoderFFVDPAU(uint32_t w, uint32_t h,uint32_t fcc, uint32_t ext
         {
             VDPAU->renders[i]=new vdpau_render_state;
             memset(VDPAU->renders[i],0,sizeof( vdpau_render_state));
-            if(VDP_STATUS_OK!=admVdpau::surfaceCreate(w,h,&(VDPAU->renders[i]->surface)))
+            if(VDP_STATUS_OK!=admVdpau::surfaceCreate(widthToUse,heightToUse,&(VDPAU->renders[i]->surface)))
             {
                 ADM_error("Cannot create surface %d/%d\n",i,NB_SURFACE);
                 alive=false;
@@ -357,6 +353,7 @@ decoderFFVDPAU::~decoderFFVDPAU()
         // released
         {
                 avcodec_close (_context);
+
                 av_free(_context);
                 _context=NULL;
         }
