@@ -45,6 +45,11 @@
 #include "ADM_script2/include/ADM_script.h"
 #include "ADM_edScriptGenerator.h"
 
+#include "ADM_edAudioTrackExternal.h"
+#include "ADM_threads.h"
+
+admMutex singleThread;
+
 renderZoom currentZoom=ZOOM_1_1;
 #include "DIA_audioTracks.h"
 //***********************************
@@ -136,6 +141,8 @@ void HandleAction (Action action)
   uint32_t nf = 0;
   uint32_t old;
 
+  admScopedMutex autolock(&singleThread); // make sure only one thread at a time calls this
+  
   ADM_warning("************ %s **************\n",getActionName(action));
 
   // handle out of band actions
@@ -326,7 +333,7 @@ void HandleAction (Action action)
           case ACT_JOG:
                 break;
           case ACT_OPEN_VIDEO:
-                GUI_FileSelRead (QT_TRANSLATE_NOOP("adm","Select AVI File..."), (SELFILE_CB *)A_openAvi);
+                GUI_FileSelRead (QT_TRANSLATE_NOOP("adm","Select Video File..."), (SELFILE_CB *)A_openAvi);
                 break;
           default:
             break;
@@ -391,10 +398,10 @@ void HandleAction (Action action)
                 break;
 
     case ACT_OPEN_VIDEO:
-        GUI_FileSelRead (QT_TRANSLATE_NOOP("adm","Select AVI File..."),(SELFILE_CB *) A_openAvi);
+        GUI_FileSelRead (QT_TRANSLATE_NOOP("adm","Select Video File..."),(SELFILE_CB *) A_openAvi);
         break;
     case ACT_APPEND_VIDEO:
-        GUI_FileSelRead (QT_TRANSLATE_NOOP("adm","Select AVI File to Append..."),(SELFILE_CB *) A_appendAvi);
+        GUI_FileSelRead (QT_TRANSLATE_NOOP("adm","Select Video File to Append..."),(SELFILE_CB *) A_appendAvi);
         break;
     case ACT_VIDEO_PROPERTIES:
         DIA_properties ();
@@ -1064,13 +1071,113 @@ roger_and_out:
 
 }
 #endif
+/**
+ * \fn extractTrackIndex
+ * @param trackIdxTxt
+ * @return 
+ */
+static inline int extractTrackIndex(const char *trackIdxTxt)
+{
+	static const int MAX_TRACK_IDX_LENGTH = 4+1; // Max length expected = 0xFF. Test 1 char more than assumed to take the \0 into account
+	size_t trackTxtLen = strlen(trackIdxTxt);
+        if(trackTxtLen>= MAX_TRACK_IDX_LENGTH)
+            trackTxtLen=MAX_TRACK_IDX_LENGTH;
+	if ( MAX_TRACK_IDX_LENGTH == trackTxtLen) 
+        {
+		GUI_Error_HIG (QT_TRANSLATE_NOOP("adm","Invalid audio index given"), NULL);
+		return -1;
+	}
+	char *endptr;
+	int trackIdx = static_cast<int>(strtol(trackIdxTxt, &endptr, 0));
+	
+	if (trackIdx < 1 || trackIdx > ADM_MAXIMUM_AMOUT_AUDIO_STREAMS || endptr != trackIdxTxt + trackTxtLen) {
+		GUI_Error_HIG (QT_TRANSLATE_NOOP("adm","Invalid audio index given"), NULL);
+		return -1;
+	}
+	return trackIdx-1;
+}
 /**
         \fn A_externalAudioTrack
         \brief Select external audio track (for 2nd track)
+		@param trackIdx The track index to use, according to the active track list
+		@param filename
 */
-void A_externalAudioTrack( void )
+void A_externalAudioTrack(const char *trackIdxTxt, const char *filename )
 {
+	int trackIdx = extractTrackIndex(trackIdxTxt);
+	if(trackIdx == -1) return;
+	printf("\texternal audio index = %d\n", trackIdx);
+	printf("\tgiven '%s'\n", filename);
+
+	ADM_edAudioTrackExternal *ext=create_edAudioExternal(filename);
+	if (!ext) {
+		GUI_Error_HIG("Error","Cannot use that file as audio track");
+		return;
+	}
+	// add to the list of the known input files
+	ActiveAudioTracks* tracks = video_body->getPoolOfActiveAudioTrack();
+	PoolOfAudioTracks *pool = video_body->getPoolOfAudioTrack();
+	int assumedIdx = pool->size();
+	pool->addInternalTrack( ext);
+	pool->dump();
+	// the shortcut insert which should work the most time
+	if (pool->size() > assumedIdx && pool->at(assumedIdx) == ext) {
+		if (trackIdx < tracks->size())
+			tracks->insertTrack(trackIdx, assumedIdx, ext);
+		else
+			tracks->insertTrack(tracks->size(), assumedIdx, ext);
+		if(tracks->size() > trackIdx+1)
+			tracks->removeTrack(trackIdx+1);
+	} else {
+		assumedIdx = -1;
+		for(int i=0; i<pool->size(); i++){
+			if(pool->at(i) == ext) {
+				assumedIdx = i;
+				break;
+			}
+		}
+		if (assumedIdx == -1) {
+			// This should never happen, but who knows?
+			GUI_Error_HIG("Error","Audio file not found in list, even than it should be there. Create a bug report!");
+			return;
+		}
+		printf("assumed Idx = %d\n", assumedIdx);
+		if(trackIdx >= tracks->size()) {
+			tracks->addTrack(assumedIdx, ext);
+		} else {
+			tracks->removeTrack(trackIdx);
+			tracks->insertTrack(trackIdx, assumedIdx, ext);
+		}
+	}
+	tracks->dump();
+	printf("external file appended");
 }
+
+/**
+    \fn A_setAudioLang
+    \brief Setting the language name for the given track index
+	@param trackIndex The track index to modify, according to the active track list
+*/
+void    A_setAudioLang(const char *trackIdxTxt, const char *langueName)
+{
+	if (!video_body->isFileOpen()) {
+		GUI_Error_HIG("Error","Unable to set the audio language: No video loaded yet!");
+		return;
+	}
+	int trackIdx = extractTrackIndex(trackIdxTxt);
+	if(trackIdx == -1) return;
+	ActiveAudioTracks* tracks = video_body->getPoolOfActiveAudioTrack();
+	if (tracks->size() == 0 ) {
+		GUI_Error_HIG("Error","Setting the language for the given track index is not possible: Video has no audio file!");
+		return;
+	} else if (tracks->size() <= trackIdx) {
+		GUI_Error_HIG("Error","Setting the language for the given track index is not possible: Invalid track index!");
+		return;
+	}
+	tracks->atEdAudio(trackIdx)->setLanguage(langueName);
+
+}
+
 /**
     \fn A_Resync
     \brief
@@ -1369,8 +1476,15 @@ int value;
     ed->audioEncodingConfig.shiftEnabled=onoff;
     ed->audioEncodingConfig.shiftInMs=value;
     update=0; 
+    return true;
 }
 
+bool avisynthPortAsCommandLineArgument = false;
+bool A_getCommandLinePort(uint32_t &port) {
+	if (avisynthPortAsCommandLineArgument)
+		prefs->get(AVISYNTH_AVISYNTH_LOCALPORT, &port);
+	return avisynthPortAsCommandLineArgument;
+}
 void A_set_avisynth_port(char *port_number_as_text){
 	// somehow strtol seems to die with EAGAIN
 	int input_length = strlen(port_number_as_text);
@@ -1379,7 +1493,7 @@ void A_set_avisynth_port(char *port_number_as_text){
 
 	for ( ; idx<input_length ; idx++ )
 		if(port_number_as_text[idx] <= '9' && port_number_as_text[idx] >= '0')
-			portNumber = portNumber*10 + port_number_as_text[0] - '0';
+			portNumber = portNumber*10 + port_number_as_text[idx] - '0';
 		else
 		{
 			fprintf(stderr,"Invalid character in port number\n");
@@ -1392,7 +1506,8 @@ void A_set_avisynth_port(char *port_number_as_text){
 		fflush(stderr);
 		exit(-1);
 	}
-	prefs->set(AVISYNTH_AVISYNTH_LOCALPORT,portNumber );
+	avisynthPortAsCommandLineArgument = true;
+	prefs->set(AVISYNTH_AVISYNTH_LOCALPORT, portNumber);
 }
 /**
  * \fn A_RunScript
