@@ -49,7 +49,7 @@ extern "C" {
 
 #include "ADM_render/GUI_sdlRender.h"
 #endif
-
+extern uint8_t GUI_close(void);
 static bool setPrefsDefault(void);
 extern bool  vdpauProbe(void);
 extern bool  libvaProbe(void);
@@ -63,11 +63,11 @@ extern void destroyGUI(void);
 extern void initFileSelector(void);
 extern void getUIDescription(char*);
 extern uint8_t ADM_ad_loadPlugins(const char *path);
-extern uint8_t ADM_vf_loadPlugins(const char *path);
+extern uint8_t ADM_vf_loadPlugins(const char *path,const char *subFolder);
 extern uint8_t ADM_vd6_loadPlugins(const char *path);
 extern uint8_t ADM_av_loadPlugins(const char *path);
 extern uint8_t ADM_ae_loadPlugins(const char *path);
-extern uint8_t ADM_ve6_loadPlugins(const char *path);
+extern uint8_t ADM_ve6_loadPlugins(const char *path,const char *subFolder);
 
 extern bool ADM_ad_cleanup(void);
 extern bool ADM_ae_cleanup(void);
@@ -90,6 +90,9 @@ extern int UI_RunApp(void);
 extern bool UI_End(void);
 extern void cleanUp (void);
 
+extern ADM_UI_TYPE UI_GetCurrentUI(void);
+
+
 #if !defined(NDEBUG) && defined(FIND_LEAKS)
 extern const char* new_progname;
 #endif
@@ -133,16 +136,41 @@ int main(int _argc, char *_argv[])
 
 	return exitVal;
 }
-
+/**
+ * \fn getUISpecifSubfolder
+ * @return 
+ */
+static const char *getUISpecifSubfolder()
+{
+    switch(UI_GetCurrentUI())
+    {
+        case ADM_UI_QT4:
+#if ADM_UI_TYPE_BUILD == ADM_UI_QT4            
+            return QT_FLAVOR;
+#else
+            return "qt4";
+#endif            
+            break;
+        case ADM_UI_CLI:
+            return "cli";
+            break;
+        case ADM_UI_GTK:
+            return "gtk";
+            break;
+        default:     
+            break;
+    }
+    return "unknown";
+}
 int startAvidemux(int argc, char *argv[])
 {
     printf("*************************\n");
-    printf("  Avidemux v" VERSION);
+    printf("  Avidemux v"ADM_VERSION);
 
-  	if(ADM_SUBVERSION)
-	{
-		printf(" (r%04u)", ADM_SUBVERSION);
-	}
+#if defined( ADM_SUBVERSION )
+#define MKSTRING(x) x
+         printf(" (%s) .", MKSTRING(ADM_SUBVERSION)); 
+#endif
 
     printf("\n*************************\n");
     printf(" http://www.avidemux.org\n");
@@ -254,7 +282,7 @@ int startAvidemux(int argc, char *argv[])
 
     //***************Plugins *********************
 
-	if(!initGUI(initialiseScriptEngines(sePlugins, video_body)))
+	if(!initGUI(initialiseScriptEngines(sePlugins, video_body,getUISpecifSubfolder())))
 	{
 		printf("\n Fatal : could not init GUI\n");
 		exit(-1);
@@ -306,13 +334,13 @@ int startAvidemux(int argc, char *argv[])
     ADM_ae_loadPlugins(aePlugins);
     delete [] aePlugins;
 
-	ADM_dm_loadPlugins(dmPlugins);
+    ADM_dm_loadPlugins(dmPlugins);
     delete [] dmPlugins;
 
-    ADM_ve6_loadPlugins(vePlugins);
+    ADM_ve6_loadPlugins(vePlugins,getUISpecifSubfolder());
     delete [] vePlugins;
 
-    ADM_vf_loadPlugins(vfPlugins);
+    ADM_vf_loadPlugins(vfPlugins,getUISpecifSubfolder());
     delete [] vfPlugins;
 
     ADM_vd6_loadPlugins(vdPlugins);
@@ -320,14 +348,14 @@ int startAvidemux(int argc, char *argv[])
 
 
     // load local audio decoder plugins
-	adPlugins=ADM_getHomeRelativePath("plugins6","audioDecoder");
-	ADM_ad_loadPlugins(adPlugins);
-	delete [] adPlugins;
+    adPlugins=ADM_getHomeRelativePath("plugins6","audioDecoder");
+    ADM_ad_loadPlugins(adPlugins);
+    delete [] adPlugins;
 
-	// load local video filter plugins
-	vfPlugins=ADM_getHomeRelativePath("plugins6","videoFilter");
-	ADM_vf_loadPlugins(vfPlugins);
-	delete [] vfPlugins;
+    // load local video filter plugins
+    vfPlugins=ADM_getHomeRelativePath("plugins6","videoFilter");
+    ADM_vf_loadPlugins(vfPlugins,getUISpecifSubfolder());
+    delete [] vfPlugins;
 
 
 	
@@ -343,26 +371,32 @@ int startAvidemux(int argc, char *argv[])
     printf("Normal exit\n");
     return 0;
 }
-extern uint8_t GUI_close(void);
+
+/**
+ * 
+ */
 void onexit( void )
 {
-	printf("Cleaning up\n");
-    if(video_body) video_body->cleanup ();
+    printf("Cleaning up\n");
+    if(video_body) 
+        video_body->cleanup ();
     delete video_body;
+    video_body=NULL;
     // wait for thread to finish executing
+    ADM_setCrashHook(NULL,NULL);
     destroyScriptEngines();
 //    filterCleanUp();
-	ADM_lavDestroy();
+    ADM_lavDestroy();
 
 #ifdef USE_SDL
 	quitSdl();
 #endif
 
 
-	AVDM_cleanup();
+    AVDM_cleanup();
 
 
-	destroyGUI();
+    destroyGUI();
     destroyPrefs();
 
     admPreview::destroy();
