@@ -13,9 +13,10 @@
  ***************************************************************************/
 
 #include <QtCore/QFileInfo>
+#include <QtCore/QMimeData>
 #include <QtCore/QUrl>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QGraphicsView>
+#include <QKeyEvent>
+#include <QGraphicsView>
 #include <QtCore/QDir>
 
 #include "ADM_cpp.h"
@@ -37,6 +38,7 @@
 #include "GUI_ui.h"
 #include "config.h"
 #include "ADM_preview.h"
+#include "DIA_defaultAskAvisynthPort.hxx"
 using namespace std;
 
 #ifdef USE_OPENGL
@@ -133,10 +135,10 @@ void MainWindow::comboChanged(int z)
 
 	if (obj == ui.comboBoxVideo)
 	{
-		bool b=FALSE;
+		bool b=false;
 		if(ui.comboBoxVideo->currentIndex())
 		{
-			b=TRUE;
+			b=true;
 		}
 		ui.pushButtonVideoConf->setEnabled(b);
 		ui.pushButtonVideoFilter->setEnabled(b);
@@ -144,10 +146,10 @@ void MainWindow::comboChanged(int z)
 	}
 	else if (obj == ui.comboBoxAudio)
 	{
-		bool b=FALSE;
+		bool b=false;
 		if(ui.comboBoxAudio->currentIndex())
 		{
-			b=TRUE;
+			b=true;
 		}
 		ui.pushButtonAudioConf->setEnabled(b);
 		ui.pushButtonAudioFilter->setEnabled(b);
@@ -200,7 +202,7 @@ void MainWindow::audioToggled(bool checked)
 		AVDM_setVolume(0);
 }
 
-void MainWindow::previewModeChanged(QAction *action)
+void MainWindow::previewModeChanged(int  flop)
 {
 	HandleAction(ACT_PreviewChanged);
 }
@@ -238,12 +240,7 @@ MainWindow::MainWindow(const vector<IScriptEngine*>& scriptEngines) : _scriptEng
 	ui.actionQuit->setMenuRole(QAction::NoRole);
 #endif
 
-	// Preview modes
-	QActionGroup *groupPreviewModes = new QActionGroup(this);
-
-	groupPreviewModes->addAction(ui.actionPreviewInput);
-	groupPreviewModes->addAction(ui.actionPreviewOutput);
-	connect(groupPreviewModes, SIGNAL(triggered(QAction*)), this, SLOT(previewModeChanged(QAction*)));
+        connect( ui.checkDisplayOut,SIGNAL(stateChanged(int)),this,SLOT(previewModeChanged(int)));
 
 	/*
 	Connect our button to buttonPressed
@@ -320,11 +317,11 @@ MainWindow::MainWindow(const vector<IScriptEngine*>& scriptEngines) : _scriptEng
 	this->setFocus(Qt::OtherFocusReason);
 
 	setAcceptDrops(true);
-    setWindowIcon(QIcon(":/new/prefix1/pics/avidemux_icon_small.png"));
+        setWindowIcon(QIcon(":/new/prefix1/pics/avidemux_icon_small.png"));
 
     // Hook also the toolbar
     connect(ui.toolBar,  SIGNAL(actionTriggered ( QAction *)),this,SLOT(searchToolBar(QAction *)));
-    connect(ui.toolBar_2,SIGNAL(actionTriggered ( QAction *)),this,SLOT(searchToolBar(QAction *)));
+    //connect(ui.toolBar_2,SIGNAL(actionTriggered ( QAction *)),this,SLOT(searchToolBar(QAction *)));
 
 	QWidget* dummy0 = new QWidget();
 	QWidget* dummy1 = new QWidget();
@@ -556,7 +553,7 @@ bool MainWindow::eventFilter(QObject* watched, QEvent* event)
 							HandleAction(ACT_Back1Second);
 						else if (keyEvent->modifiers() == Qt::ControlModifier)
 							HandleAction(ACT_Back2Seconds);
-						else if (keyEvent->modifiers() == Qt::ControlModifier | Qt::ShiftModifier)
+						else if (keyEvent->modifiers() == (Qt::ControlModifier | Qt::ShiftModifier))
 							HandleAction(ACT_Back4Seconds);
 						else
 							HandleAction(ACT_PreviousFrame);
@@ -567,7 +564,7 @@ bool MainWindow::eventFilter(QObject* watched, QEvent* event)
 							HandleAction(ACT_Forward1Second);
 						else if (keyEvent->modifiers() == Qt::ControlModifier) 
 							HandleAction(ACT_Forward2Seconds);
-						else if (keyEvent->modifiers() == Qt::ControlModifier | Qt::ShiftModifier) 
+						else if (keyEvent->modifiers() == (Qt::ControlModifier | Qt::ShiftModifier)) 
 							HandleAction(ACT_Forward4Seconds);
 						else 
 							HandleAction(ACT_NextFrame);
@@ -815,20 +812,13 @@ void UI_refreshCustomMenu(void)
 */
 int UI_getCurrentPreview(void)
 {
-	int index;
-
-	if (WIDGET(actionPreviewOutput)->isChecked())
-		index = 1;
-	else if (WIDGET(actionPreviewSide)->isChecked())
-		index = 2;
-	else if (WIDGET(actionPreviewTop)->isChecked())
-		index = 3;
-	else if (WIDGET(actionPreviewSeparate)->isChecked())
-		index = 4;
-	else
-		index = 0;
-
-	return index;
+    if(WIDGET(checkDisplayOut)->isChecked()) 
+    {
+        printf("Output is ON\n");
+        return 1;
+    }
+    printf("Output is Off\n");
+    return 0;
 }
 
 /**
@@ -837,24 +827,7 @@ int UI_getCurrentPreview(void)
 */
 void UI_setCurrentPreview(int ne)
 {
-	switch (ne)
-	{
-		case 1:
-			WIDGET(actionPreviewOutput)->setChecked(true);
-			break;
-		case 2:
-			WIDGET(actionPreviewSide)->setChecked(true);
-			break;
-		case 3:
-			WIDGET(actionPreviewTop)->setChecked(true);
-			break;
-		case 4:
-			WIDGET(actionPreviewSeparate)->setChecked(true);
-			break;
-		default:
-			WIDGET(actionPreviewInput)->setChecked(true);
-			break;
-	}
+        WIDGET(checkDisplayOut)->setChecked(true);
 }
 /**
         \fn FatalFunctionQt
