@@ -15,16 +15,29 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <QtGui/QFrame>
-#include <QtGui/QImage>
-#include <QtGui/QPainter>
-#include <QtGui/QPaintEngine>
+
+#include <QFrame>
+
+
+#include <QImage>
+#include <QPainter>
+#include <QPaintEngine>
 
 /* Probably on unix/X11 ..*/
 #ifdef __APPLE__
 #include <Carbon/Carbon.h>
 #elif !defined(_WIN32)
-#include <QtGui/QX11Info>
+
+#if QT_VERSION < QT_VERSION_CHECK(5,0,0) 
+        #include <QX11Info> // removed in qt5
+#else
+extern "C"
+{
+        extern void *XOpenDisplay(    char *name);
+}
+#endif
+
+
 #endif
 
 #include "ADM_assert.h"
@@ -193,11 +206,11 @@ void  UI_updateDrawWindowSize(void *win,uint32_t w,uint32_t h)
 void UI_getWindowInfo(void *draw, GUI_WindowInfo *xinfo)
 {
     ADM_assert(videoWindow);
-	QWidget* widget = videoWindow->parentWidget();
+    QWidget* widget = videoWindow->parentWidget();
     xinfo->widget = videoWindow;
 
 #if defined(_WIN32)
-	xinfo->display=videoWindow->winId();
+	xinfo->display=(void *)videoWindow->winId();
 #elif defined(__APPLE__)
 	#if defined(ADM_CPU_X86_64)
 		xinfo->display = (void*)videoWindow->winId();
@@ -207,10 +220,15 @@ void UI_getWindowInfo(void *draw, GUI_WindowInfo *xinfo)
 		xinfo->window = 0;
 	#endif
 #else
-    const QX11Info &info=videoWindow->x11Info();
-    xinfo->display=info.display();
-   // xinfo->window=videoWindow->winId();
-    xinfo->window=videoWindow->winId();
+        #if QT_VERSION < QT_VERSION_CHECK(5,0,0) 
+                const QX11Info &info=videoWindow->x11Info();
+                xinfo->display=info.display();
+                // xinfo->window=videoWindow->winId();
+                xinfo->window=videoWindow->winId();
+        #else
+                xinfo->window=videoWindow->winId();
+                xinfo->display=XOpenDisplay(NULL);
+        #endif
 #endif
 
 	xinfo->x = widget->x();
