@@ -49,8 +49,80 @@ extern int ff_h264_info(AVCodecParserContext *parser,ffSpsInfo *ndo);
 
 #define MAX_NALU_PER_CHUNK 20
 
+
+/**
+    \fn ADM_getH264SpsPpsFromExtraData
+    \brief Returns a copy of PPS/SPS extracted from extrdata
+*/
+static bool ADM_SPSannexBToMP4(uint32_t dataLen,uint8_t *incoming,
+                                    uint32_t *outLen, uint8_t *outData)
+{
+    if(dataLen>200)
+    {
+        ADM_warning("SPS TOO LONG\n");
+        return false;
+    }
+    // 01
+    // 4d 40 1f ff 
+    // e1 00 1b 67 
+    // 4d 40 1f f6 
+    // 02 80 2d
+
+    outData[0]=1;
+    outData[1]=0x4d;
+    outData[2]=0x40;
+    outData[3]=0x1f;
+    outData[4]=0xff;
+    outData[5]=0xe1; // 1 stream
+    outData[6]=0; // Len MSB
+    outData[7]=0; // Len LSB, should fit in 1 byte...
+    outData[8]=0x67; // Len LSB, should fit in 1 byte...
+#if 1
+    memcpy(outData+9,incoming,dataLen);
+    int p=dataLen+9;
+#else
+    int p=ADM_unescapeH264(dataLen,incoming,outData+9) ;
+#endif
+    outData[7]=p; // Len LSB, should fit in 1 byte...
+    *outLen= p+9;
+    return true;
+}
+
 bool ADM_findMpegStartCode (uint8_t * start, uint8_t * end,
 			    uint8_t * outstartcode, uint32_t * offset);
+/**
+    \fn ADM_escapeH264
+    \brief Add escape stuff
+
+*/
+uint32_t ADM_escapeH264 (uint32_t len, uint8_t * in, uint8_t * out)
+{
+  uint32_t outlen = 0;
+  uint8_t *tail = in + len;
+  if (len < 2)
+    return 0;
+  while (in < tail-1 )
+    {
+      if (!in[0] && !in[1])
+	{
+	  out[0] = 0;
+	  out[1] = 0;
+          out[2] = 3;
+	  out += 3;
+	  outlen += 3;
+	  in += 2;
+          continue;
+	}
+      *out++ = *in++;
+      outlen++;
+    }
+  // copy last bytes
+  uint32_t left = tail - in;
+  memcpy (out, in, left);
+  outlen += left;
+  return outlen;
+
+}
 /**
     \fn unescapeH264
     \brief Remove escape stuff
@@ -71,6 +143,7 @@ uint32_t ADM_unescapeH264 (uint32_t len, uint8_t * in, uint8_t * out)
 	  out += 2;
 	  outlen += 2;
 	  in += 3;
+          continue;
 	}
       *out++ = *in++;
       outlen++;
@@ -380,17 +453,46 @@ static bool getRecoveryFromSei(uint32_t nalSize, uint8_t *org,uint32_t *recovery
 {
     
     uint8_t *payloadBuffer=(uint8_t *)malloc(nalSize+16);
+    int     originalNalSize=nalSize+16;
     uint8_t *payload=payloadBuffer;
     bool r=false;
     nalSize=ADM_unescapeH264(nalSize,org,payload);
+    if(nalSize>originalNalSize)
+    {
+        ADM_warning("NAL is way too big : %d, while we expected %d at most\n",nalSize,originalNalSize);
+        free(payloadBuffer);
+        return false;
+    }        
+    
     uint8_t *tail=payload+nalSize;
     *recoveryLength=16;
     while( payload<tail)
     {
                 uint32_t sei_type=0,sei_size=0;
-                while(payload[0]==0xff) {sei_type+=0xff;payload++;};
+                while(payload[0]==0xff) 
+                {
+                        sei_type+=0xff;payload++;
+                        if(payload+2>=tail) 
+                        {
+                            ADM_warning("Cannot decode SEI\n");
+                            goto abtSei;
+                        }
+                };
                 sei_type+=payload[0];payload++;
-                while(payload[0]==0xff) {sei_size+=0xff;payload++;};
+                if(payload>=tail)
+                {
+                            ADM_warning("Cannot decode SEI\n");
+                            goto abtSei;                    
+                }
+                while(payload[0]==0xff) 
+                {
+                    sei_size+=0xff;payload++;
+                    if(payload+1>=tail) 
+                        {
+                            ADM_warning("Cannot decode SEI (2)\n");
+                            goto abtSei;
+                        }                    
+                };
                 sei_size+=payload[0];payload++;
                 aprintf("  [SEI] Type : 0x%x size:%d\n",sei_type,sei_size);
                 if(payload+sei_size>tail) break;
@@ -409,6 +511,7 @@ static bool getRecoveryFromSei(uint32_t nalSize, uint8_t *org,uint32_t *recovery
                             break;
                 }
     }
+abtSei:
     free(payloadBuffer);
     return r;
 }
@@ -567,27 +670,22 @@ uint8_t extractH264FrameType_startCode(uint32_t nalSize, uint8_t * buffer,uint32
   printf ("No stream\n");
   return 0;
 }
-/**
-        \fn extractSPSInfo2
-        \brief Same as extractSPSInfo, but using libavcodec
-*/
-uint8_t extractSPSInfo_lavcodec (uint8_t * data, uint32_t len, ADM_SPSInfo *spsinfo)
-{
-    static const uint8_t sig[5]={0,0,0,1,0};
-    uint32_t myLen=len+5+5+FF_INPUT_BUFFER_PADDING_SIZE;
-    uint8_t *myData = new uint8_t[myLen];
-    bool r=false;
 
-    memset(myData,myLen,1);
-    mixDump(data,len);
-    // put dummy SPS tag + dummy filler at the end
-    // so that lavcodec can split it
-    memcpy(myData,sig,5);
-    memcpy(myData+5,data,len);
-    memcpy(myData+5+len,sig,5);
-    myData[4]=NAL_SPS;
-    myData[5+len+4]=NAL_FILLER;
-    
+
+/**
+        \fn extractSPSInfo_mp4Header
+        \brief Only works for mp4 style headers i.e. begins by 0x01
+*/
+bool extractSPSInfo_mp4Header (uint8_t * data, uint32_t len, ADM_SPSInfo *spsinfo)
+{
+    bool r=false;
+    bool closeCodec=false;
+        
+    // duplicate
+    int myLen=len+FF_INPUT_BUFFER_PADDING_SIZE;
+    uint8_t *myData=new uint8_t[myLen];
+    memset(myData,0x2,myLen);
+    memcpy(myData,data,len);
     
     // 1-Create parser
     AVCodecParserContext *parser=av_parser_init(CODEC_ID_H264);
@@ -608,21 +706,28 @@ uint8_t extractSPSInfo_lavcodec (uint8_t * data, uint32_t len, ADM_SPSInfo *spsi
         goto theEnd;
     }
     ADM_info("Codec created\n");
-    ctx=avcodec_alloc_context();
-   if (avcodec_open(ctx, codec) < 0)  
+    ctx=avcodec_alloc_context3(codec);
+   if (avcodec_open2(ctx, codec, NULL) < 0)  
    {
         ADM_error("cannot create h264 context\n");
         goto theEnd;
     }
+
     ADM_info("Context created\n");
     //2- Parse, let's add SPS prefix + Filler postfix to make life easier for libavcodec parser
     ctx->extradata=myData;
-    ctx->extradata_size=myLen;
+    ctx->extradata_size=len;
      {
          uint8_t *outptr=NULL;
          int outsize=0;
 
-         av_parser_parse2(parser, ctx, &outptr, &outsize, d, 0, 0, 0,0);
+         int used=av_parser_parse2(parser, ctx, &outptr, &outsize, d, 0, 0, 0,0);
+         printf("Used bytes %d/%d (+5)\n",used,len);
+         if(!used)
+         {
+             ADM_warning("Failed to extract SPS info\n");
+           //  goto theEnd;
+         }
     }
     ADM_info("Width  : %d\n",ctx->width);
     ADM_info("Height : %d\n",ctx->height);
@@ -651,6 +756,7 @@ theEnd:
     if(ctx)
     {
         avcodec_close(ctx);
+
         av_free(ctx);
     }
     if(parser)
@@ -661,20 +767,54 @@ theEnd:
     return r;
 }
 
+
+/**
+        \fn extractSPSInfo2
+        \brief Same as extractSPSInfo, but using libavcodec
+*/
+uint8_t extractSPSInfo_lavcodec (uint8_t * data, uint32_t len, ADM_SPSInfo *spsinfo)
+{
+    if(data[0]==1) return extractSPSInfo_mp4Header(data,len,spsinfo);
+    
+    ADM_info("Incoming SPS info\n");
+    mixDump(data,len);
+    
+    ADM_info("\nconverted SPS info\n");
+    
+    uint32_t converted;
+    uint8_t buffer[256];
+    if(! ADM_SPSannexBToMP4(len,data,&converted,buffer))
+    {
+        ADM_warning("Cannot convert SPS\n");
+        return false;
+    }
+    mixDump(buffer,converted);
+    ADM_info("\n");
+    return    extractSPSInfo_mp4Header(buffer,converted,spsinfo) ;
+    
+}
+
 uint8_t extractSPSInfo (uint8_t * data, uint32_t len, ADM_SPSInfo *spsinfo)
 {
 #define DPY(x) ADM_info(#x":%d\n",(int)spsinfo->x);
 #if 1        
         
         bool l=extractSPSInfo_lavcodec(data,len,spsinfo);
-        DPY(width);
-        DPY(height);
-        DPY(fps1000);
-        DPY(hasStructInfo);
-        DPY(CpbDpbToSkip);
-        DPY(darNum);
-        DPY(darDen);
+        if(l)
+        {
+            DPY(width);
+            DPY(height);
+            DPY(fps1000);
+            DPY(hasStructInfo);
+            DPY(CpbDpbToSkip);
+            DPY(darNum);
+            DPY(darDen);
+        }else
+        {
+            ADM_info("Failed\n.");
+        }
         return l;
+        
 #else           
         bool i=extractSPSInfo_internal(data,len,spsinfo);
         DPY(width);
