@@ -17,8 +17,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#ifndef ADM_FFMP43_H
-#define ADM_FFMP43_H
+#pragma once
 
 #include "ADM_coreVideoCodec6_export.h"
 
@@ -37,17 +36,23 @@ class ADM_COREVIDEOCODEC6_EXPORT decoderFF:public decoders
 {
 protected:
   bool  hurryUp;
+  bool _setBpp;
+  bool _setFcc;
   int codecId;
   uint8_t _refCopy;
+  uint32_t _bpp;
   AVCodecContext *_context;
   uint8_t  *_extraDataCopy;
-  AVFrame _frame;
+  int _extraDataLen;
+  uint32_t _fcc;
+  AVFrame *_frame;
   uint8_t _allowNull;
   uint32_t frameType (void);
   uint8_t clonePic (AVFrame * src, ADMImage * out);
   void decoderMultiThread ();
   uint32_t _gmc;
   uint32_t _usingMT;
+  uint32_t _threads;
 
 	typedef struct {
 		bool swapUv;
@@ -136,6 +141,16 @@ public:
   bool   uncompress (ADMCompressedImage * in, ADMImage * out);
 };
 
+class decoderFFH265:public decoderFF
+{
+public:
+  decoderFFH265 (uint32_t w, uint32_t h,uint32_t fcc, uint32_t extraDataLen, uint8_t *extraData,uint32_t bpp);
+  virtual bool bFramePossible (void)
+  {
+      return true;
+  }
+};
+
 class decoderFFhuff:public decoderFF
 {
 protected:
@@ -159,7 +174,58 @@ public:
 ADM_COREVIDEOCODEC6_EXPORT void ADM_lavInit(void);
 ADM_COREVIDEOCODEC6_EXPORT void ADM_lavDestroy(void);
 
-#endif
+
+#define FF_SHOW		(FF_DEBUG_VIS_MV_P_FOR+	FF_DEBUG_VIS_MV_B_FOR+FF_DEBUG_VIS_MV_B_BACK)
+
+#define WRAP_Open_Template(funcz,argz,display,codecid,extra) \
+{\
+AVCodec *codec=funcz(argz);\
+if(!codec) {GUI_Error_HIG("Codec",QT_TR_NOOP("Internal error finding codec"display));ADM_assert(0);} \
+  codecId=codecid; \
+  _context = avcodec_alloc_context3 (codec);\
+  ADM_assert (_context);\
+  _context->max_b_frames = 0;\
+  _context->width = _w;\
+  _context->height = _h;\
+  _context->pix_fmt = PIX_FMT_YUV420P;\
+  _context->debug_mv |= FF_SHOW;\
+  _context->debug |= FF_DEBUG_VIS_MB_TYPE + FF_DEBUG_VIS_QP;\
+  _context->workaround_bugs=1*FF_BUG_AUTODETECT +0*FF_BUG_NO_PADDING; \
+  _context->error_concealment=3; \
+  if (_setBpp) {\
+    _context->bits_per_coded_sample = _bpp;\
+  }\
+  if (_setFcc) {\
+    _context->codec_tag=_fcc;\
+    _context->stream_codec_tag=_fcc;\
+  }\
+  if (_extraDataCopy) {\
+    _context->extradata = _extraDataCopy;\
+    _context->extradata_size = _extraDataLen;\
+  }\
+  if (_usingMT) {\
+    _context->thread_count = _threads;\
+  }\
+  extra \
+  \
+  if (avcodec_open2(_context, codec, NULL) < 0)  \
+                      { \
+                                        printf("[lavc] Decoder init: "display" video decoder failed!\n"); \
+                                        GUI_Error_HIG("Codec","Internal error opening "display); \
+                                        ADM_assert(0); \
+                                } \
+                                else \
+                                { \
+                                        printf("[lavc] Decoder init: "display" video decoder initialized! (%s)\n",codec->long_name); \
+                                } \
+}
+
+#define WRAP_Open(x)            {WRAP_Open_Template(avcodec_find_decoder,x,#x,x,;);}
+#define WRAP_OpenByName(x,y)    {WRAP_Open_Template(avcodec_find_decoder_by_name,#x,#x,y,;);}
+
+
+
+
 
 // EOF
 
