@@ -20,6 +20,7 @@ Not sure if the timestamp is PTS or DTS (...)
 #include "ADM_default.h"
 #include "fourcc.h"
 #include "DIA_coreToolkit.h"
+#include "ADM_videoInfoExtractor.h"
 
 #include "ADM_flv.h"
 
@@ -31,9 +32,10 @@ Not sure if the timestamp is PTS or DTS (...)
 #endif
 // Borrowed from lavformt/flv.h
 #include "libavformat/flv.h"
+#include "libavutil/intfloat.h"
 // Borrowed from lavformt/flv.h
 uint32_t ADM_UsecFromFps1000(uint32_t fps1000);
-extern uint8_t extractH263FLVInfo(uint8_t *buffer,uint32_t len,uint32_t *w,uint32_t *h);
+
 
 /**
     \fn Skip
@@ -119,9 +121,6 @@ static uint8_t stringz[FLV_MAX_STRING+1];
     stringz[size]=0;
     return (char *)stringz;
 }
-extern "C" {
-double av_int2dbl(int64_t v);
-}
 
 /**
     \fn setProperties
@@ -224,7 +223,7 @@ bool flvHeader::parseOneMeta(const char *stri,uint64_t endPos,bool &end)
                                             uint64_t hi,lo;
                                             hi=read32();lo=read32();
                                             hi=(hi<<32)+lo;
-                                            val=(float)av_int2dbl(hi);
+                                            val=(float)av_int2double(hi);
                                             printf("->%f",val);
                                             setProperties(stri,val);
                                         }
@@ -517,6 +516,31 @@ uint8_t flvHeader::open(const char *name)
 
   // Udpate frame count etc..
   ADM_info("\n[FLV] Found %u frames\n",videoTrack->_nbIndex);
+  
+  if(!metaWidth && !metaHeight &&  videoCodec==FLV_CODECID_H264)
+  {
+      ADM_info("No width / height, trying to get them..\n");
+      ADM_SPSInfo spsinfo;
+      if(extractSPSInfo_mp4Header(videoTrack->extraData,videoTrack->extraDataLen,&spsinfo))
+      {
+                ADM_info("W %d\n",spsinfo.width);
+                ADM_info("H %d\n",spsinfo.height);
+                if(spsinfo.width && spsinfo.height)
+                {
+                    metaWidth=spsinfo.width;
+                    metaHeight=spsinfo.height;
+                    updateDimensionWithMeta(FLV_CODECID_H264);
+                }else
+                {
+                        ADM_warning("Cannot decode SPS\n");
+                }
+      }else
+      {
+          ADM_warning("Cannot extract pps and sps\n");
+      }
+          
+  }
+  
    _videostream.dwLength= _mainaviheader.dwTotalFrames=videoTrack->_nbIndex;
    // Compute average fps
     float f=_videostream.dwLength;
@@ -880,7 +904,7 @@ uint32_t flvHeader::getFlags(uint32_t frame,uint32_t *flags)
 */
 uint64_t flvHeader::getTime(uint32_t frame)
 {
-     if(frame>=videoTrack->_nbIndex) return 0;
+     if(frame>=videoTrack->_nbIndex) return ADM_NO_PTS;
      flvIndex *idx=&(videoTrack->_index[frame]);
      return idx->ptsUs;
 }
