@@ -166,6 +166,7 @@ bool MP4Header::refineFps(void)
            _mainaviheader.dwMicroSecPerFrame=ADM_UsecFromFps1000(_videostream.dwRate);
         }
     }
+    return true;
     
 }
 uint8_t  MP4Header::getFrame(uint32_t framenum,ADMCompressedImage *img)
@@ -189,6 +190,7 @@ MP4Index *idx=&(VDEO.index[framenum]);
     img->demuxerDts=idx->dts;
     img->demuxerPts=idx->pts;
     aprintf("[MP4] Pts=%s\n",ADM_us2plain(idx->pts));
+    aprintf("[MP4] Dts=%s\n",ADM_us2plain(idx->dts));
     /*
     if(img->demuxerPts==ADM_COMPRESSED_NO_PTS)
         img->demuxerPts=img->demuxerDts;
@@ -227,6 +229,7 @@ MP4Header::MP4Header(void)
         _videoScale=1;
         _videoFound=0;
         delayRelativeToVideo=0;
+        _flavor=Mp4Regular;
 }
 /**
     \fn getAudioInfo
@@ -344,22 +347,32 @@ uint8_t    MP4Header::open(const char *name)
 
         if(!lookupMainAtoms((void*) atom))
         {
-          printf("Cannot find needed atom\n");
-          fclose(_fd);
-          _fd=NULL;
-		  delete atom;
-          return 0;
+          printf("Cannot find needed atom\n");   
+          if(!_tracks[0].fragments.size() || !indexVideoFragments(0)) // fixme audio
+          {
+            fclose(_fd);
+            _fd=NULL;
+            delete atom;
+            return 0;
+          }else
+          { // do other tracks as well
+              for(int i=1;i<=nbAudioTrack;i++)
+              {
+                  if(_tracks[i].fragments.size())
+                      indexAudioFragments(i);
+              }
+          }
         }
 
         delete atom;
 
-	      _isvideopresent=1;
-	      _isaudiopresent=0;
+        _isvideopresent=1;
+        _isaudiopresent=0;
 
-              _videostream.fccType=fourCC::get((uint8_t *)"vids");
-              _video_bih.biBitCount=24;
-              _videostream.dwInitialFrames= 0;
-              _videostream.dwStart= 0;
+        _videostream.fccType=fourCC::get((uint8_t *)"vids");
+        _video_bih.biBitCount=24;
+        _videostream.dwInitialFrames= 0;
+        _videostream.dwStart= 0;
 
 	printf("\n");
 
@@ -513,8 +526,33 @@ uint8_t    MP4Header::open(const char *name)
         ADM_info("Last video PTS : %s\n",ADM_us2plain(_tracks[0].index[nb-1].pts));
         ADM_info("Last video DTS : %s\n",ADM_us2plain(_tracks[0].index[nb-1].dts));
 
+        checkDuplicatedPts();
+        
         return 1;
 }
+bool MP4Header::checkDuplicatedPts(void)
+{
+        int nb=(int)_tracks[0].nbIndex;
+        for(int i=0;i<nb;i++)
+        {
+            int mn,mx;
+            mn=i-10;
+            if(mn<0) mn=0;
+            mx=i+10;
+            if(mx>=nb-1) mx=nb-1;
+            for(int j=mn;j<mx;j++)
+            {
+                if(j==i) continue;
+                if(_tracks[0].index[i].pts==_tracks[0].index[j].pts)
+                {
+                    ADM_warning("Duplicate pts %s at %d and %d\n",ADM_us2plain(_tracks[0].index[i].pts),i,j);
+                    _tracks[0].index[j].pts+=1000; // add 1 ms
+                }
+            }
+                
+        }
+        return true;
+}
 /**
  * \fn adjustElstDelay
  * @return 
@@ -552,7 +590,7 @@ bool MP4Header::shiftTimeBy(uint64_t shift)
             VDEO.index[i].pts=pts;
         }
 
-       shiftAudioTimeBy(shift);
+        shiftAudioTimeBy(shift);
         return true;        
 }
 bool MP4Header::shiftAudioTimeBy(uint64_t shift)
@@ -570,6 +608,7 @@ bool MP4Header::shiftAudioTimeBy(uint64_t shift)
                         _tracks[audioTrack+1].index[i].dts=dts;
              }
         }
+    return true;
 }
 
 //
@@ -614,8 +653,8 @@ bool    MP4Header::getPtsDts(uint32_t frame,uint64_t *pts,uint64_t *dts)
 
     if(frame>=VDEO.nbIndex)
     {
-      printf("[MKV] Frame %"PRIu32" exceeds # of frames %"PRIu32"\n",frame,VDEO.nbIndex);
-      return 0;
+      printf("[MP4] Frame %"PRIu32" exceeds # of frames %"PRIu32"\n",frame,VDEO.nbIndex);
+      return false;
     }
 
     MP4Index *idx=&(VDEO.index[frame]);
@@ -631,7 +670,7 @@ bool    MP4Header::setPtsDts(uint32_t frame,uint64_t pts,uint64_t dts)
 {
     if(frame>=VDEO.nbIndex)
     {
-      printf("[MKV] Frame %"PRIu32" exceeds # of frames %"PRIu32"\n",frame,VDEO.nbIndex);
+      printf("[MP4] Frame %"PRIu32" exceeds # of frames %"PRIu32"\n",frame,VDEO.nbIndex);
       return 0;
     }
 
