@@ -1,7 +1,8 @@
 /***************************************************************************
 
-    copyright            : (C) 2007 by mean
+    copyright            : (C) 2007/2015 by mean
     email                : fixounet@free.fr
+ * https://arashafiei.wordpress.com/2012/11/13/quick-dash/
  ***************************************************************************/
 
 /***************************************************************************
@@ -89,10 +90,12 @@ uint8_t     MP4Header::lookupMainAtoms(void *ztom)
 {
 
   adm_atom *tom=(adm_atom *)ztom;
-  adm_atom *moov;
+  adm_atom *moov,*moof=NULL;
+  bool success=true;
   ADMAtoms id;
   uint32_t container;
   printf("Analyzing file and atoms\n");
+  
   if(!ADM_mp4SimpleSearchAtom(tom, ADM_MP4_MOOV,&moov))
   {
        ADM_warning("Cannot locate moov atom\n");
@@ -104,7 +107,7 @@ uint8_t     MP4Header::lookupMainAtoms(void *ztom)
     adm_atom son(moov);
     if(!ADM_mp4SearchAtomName(son.getFCC(), &id,&container))
     {
-      aprintf("Found atom %s unknown\n",fourCC::tostringBE(son.getFCC()));
+      aprintf("[Lookup]Found atom %s unknown\n",fourCC::tostringBE(son.getFCC()));
     }
     else
     {
@@ -115,7 +118,7 @@ uint8_t     MP4Header::lookupMainAtoms(void *ztom)
             if(!parseTrack(&son))
             {
                 printf("Parse Track failed\n");
-                return false;
+                success=false;
             } ;
             break;
         default :
@@ -128,8 +131,33 @@ uint8_t     MP4Header::lookupMainAtoms(void *ztom)
     son.skipAtom();
   }
   delete moov;
+  if(!success)
+  {
+    if(!ADM_mp4SimpleSearchAtom(tom, ADM_MP4_MOOF,&moof))
+    {
+         ADM_info("Cannot find all needed atoms\n");
+    }else
+    {
+         ADM_info("It is a Dash/fragmented file\n");
+          _flavor=Mp4Dash;
+          int moofFound=1;
+         while(1)
+         {
+             parseMoof(*moof);
+             delete moof;         
+             moof=NULL;
+             if(!ADM_mp4SimpleSearchAtom(tom, ADM_MP4_MOOF,&moof))
+             {
+                 break;
+             }
+             moofFound++;
+         }
+          ADM_info("Found %d fragments\n",moofFound);        
+   }
+  }
+  
   printf("Done finding main atoms\n");
-  return 1;
+  return success;
 }
 /**
       \fn parseMvhd
@@ -185,7 +213,7 @@ uint8_t MP4Header::parseTrack(void *ztom)
      adm_atom son(tom);
      if(!ADM_mp4SearchAtomName(son.getFCC(), &id,&container))
      {
-       aprintf("Found atom %s unknown\n",fourCC::tostringBE(son.getFCC()));
+       aprintf("[Track]Found atom %s unknown\n",fourCC::tostringBE(son.getFCC()));
        son.skipAtom();
        continue;
      }
