@@ -111,9 +111,9 @@ TsIndexer::TsIndexer(listOfTsAudioTracks *trk)
     pkt=NULL;
     audioTracks=NULL;
     beginConsuming=0;
-    ui=createWorking ("Indexing");
+    gui=NULL;
     audioTracks=trk;
-    ticktock.reset();
+    processedThisRound=0;
 }
 
 /**
@@ -123,22 +123,19 @@ TsIndexer::~TsIndexer()
 {
     if(index) qfclose(index);
     if(pkt) delete pkt;
-    if(ui) delete ui;
-    ui=NULL;
+    if(gui) delete gui;
+    gui=NULL;
 }
 /**
     \fn updateUI
+ *  \brief return false if abort is needed
 */
-void TsIndexer::updateUI(void)
+bool  TsIndexer::updateUI(void)
 {
-        if(ticktock.getElapsedMS()<1000) return;
-        ticktock.reset();
-        uint64_t p;
-        p=pkt->getPos();
-        float pos=p;
-        pos=pos/(float)fullSize;
-        pos*=100;
-        ui->update( (uint32_t)pos);
+    int p=++processedThisRound;
+        processedThisRound=0;
+        return !gui->update(p, pkt->getPos());
+    
 }
 /**
     \fn writeVideo
@@ -313,7 +310,11 @@ bool TsIndexer::addUnit(indexerData &data,int unitType2,const H264Unit &unit,uin
             if(listOfUnits[n-1].unitType==unitTypePic)
             {
                 dumpUnits(data,myUnit.consumedSoFar-overRead,&(unit.packetInfo));
-                updateUI();
+                if(!updateUI())
+                {
+                    ADM_info("Indexer : cancelling\n");
+                    return false;
+                }
             }
         listOfUnits.push_back(myUnit);
         return true;
